EVP_DecodeBlock

Function EVP_DecodeBlock 

pub unsafe extern "C" fn EVP_DecodeBlock(
    dst: *mut u8,
    src: *const u8,
    src_len: usize,
) -> c_int
@brief Decodes Base64 bytes from src and writes value to dst.

@param [out] dst Decoded bytes @param [in] src Base64 encoded bytes @param [in] src_len Number of bytes to decode

@returns Number of bytes written or -1 on error

@warning EVP_DecodeBlock’s return value does not take padding into account. It also strips leading whitespace and trailing whitespace and minuses.

@deprecated OpenSSL provides a streaming base64 implementation, however its behavior is very specific to PEM. It is also very lenient of invalid input. Use of any of these functions is thus deprecated.