EVP_EncodeBlock

Function EVP_EncodeBlock 

pub unsafe extern "C" fn EVP_EncodeBlock(
    dst: *mut u8,
    src: *const u8,
    src_len: usize,
) -> usize
@brief Base64 encodes bytes from src into dst.

@details Base64 encodes src_len bytes from src and writes the result to dst with a trailing NULL.

@param [out] dst Base64 encoded value @param [in] src Bytes to encode @param [in] src_len Number of bytes to encode

@return The number of bytes written, not including the trailing NULL