EVP_EncodeInit

Function EVP_EncodeInit 

pub unsafe extern "C" fn EVP_EncodeInit(ctx: *mut EVP_ENCODE_CTX)
@brief Initialises *ctx.

@details This is typically stack allocated, for an encoding operation.

@param [in,out] ctx Context to initialize

@warning The encoding operation breaks its output with newlines every 64 characters of output (48 characters of input). Use #EVP_EncodeBlock to encode raw base64.

@deprecated OpenSSL provides a streaming base64 implementation, however its behavior is very specific to PEM. It is also very lenient of invalid input. Use of any of these functions is thus deprecated.