EVP_EncodeUpdate

Function EVP_EncodeUpdate 

pub unsafe extern "C" fn EVP_EncodeUpdate(
    ctx: *mut EVP_ENCODE_CTX,
    out: *mut u8,
    out_len: *mut c_int,
    in_: *const u8,
    in_len: usize,
) -> c_int
@brief Encodes bytes from in to Base64 and writes the value to out.

@details Some state may be contained in ctx so #EVP_EncodeFinal must be used to flush it before using the encoded data.

@param [in,out] ctx Encoding context @param [out] out Base64 encoded value @param [out] out_len Number of bytes written @param [in] in Input buffer @param [in] in_len Number of bytes to encode

@retval 1 Success @retval 0 Failure or in_len was 0

@deprecated OpenSSL provides a streaming base64 implementation, however its behavior is very specific to PEM. It is also very lenient of invalid input. Use of any of these functions is thus deprecated.