#[repr(C)]pub struct evp_encode_ctx_st {
pub data_used: c_uint,
pub data: [u8; 48],
pub eof_seen: c_char,
pub error_encountered: c_char,
}Expand description
@struct evp_encode_ctx_st Encoding Context
Fields
data_used: c_uint@brief Number of valid bytes
@details
When encoding, data will be filled and encoded as a lump. When decoding,
only the first four bytes of data will be used.
data: [u8; 48]@brief Encoded or decoded data.
eof_seen: c_char@brief Indicates that the end of the base64 data has been seen.
@details Only used when decoding. Only whitespace can follow.
error_encountered: c_char@brief indicates that invalid base64 data was found.
@details This will gitcause all future calls to fail.