pub unsafe extern "C" fn EVP_DecodeInit(ctx: *mut EVP_ENCODE_CTX)Expand description
@brief Initialises *ctx for a decoding operation.
@details This is typically stack allocated.
@param [in,out] ctx Context to initialize
@todo davidben: This isn’t a straight-up base64 decode either. Document and/or fix exactly what’s going on here; maximum line length and such.
@deprecated OpenSSL provides a streaming base64 implementation, however its behavior is very specific to PEM. It is also very lenient of invalid input. Use of any of these functions is thus deprecated.