pub unsafe extern "C" fn EVP_DecodeUpdate(
ctx: *mut EVP_ENCODE_CTX,
out: *mut u8,
out_len: *mut c_int,
in_: *const u8,
in_len: usize,
) -> c_intExpand description
@brief Decodes bytes from in and writes the decoded data to out.
@details
Some state may be contained in ctx so #EVP_DecodeFinal must be used to
flush it before using the decoded data.
@param [in,out] ctx Decoding context @param [out] out Decoded bytes @param [out] out_len Number of bytes written @param [in] in Input buffer @param [in] in_len Number of bytes to decode
@retval -1 Error @retval 0 The line was short (i.e., it was the last line) @retval 1 A full line of input was processed
@deprecated OpenSSL provides a streaming base64 implementation, however its behavior is very specific to PEM. It is also very lenient of invalid input. Use of any of these functions is thus deprecated.