pub unsafe extern "C" fn EVP_EncodeFinal(
ctx: *mut EVP_ENCODE_CTX,
out: *mut u8,
out_len: *mut c_int,
)Expand description
@brief Flushes any remaining output bytes from ctx to out.
@param [in,out] ctx Encoding context @param [out] out Output buffer @param [out] out_len Number of bytes written to buffer
@deprecated OpenSSL provides a streaming base64 implementation, however its behavior is very specific to PEM. It is also very lenient of invalid input. Use of any of these functions is thus deprecated.